@@ -63,7 +63,7 @@ class HonParameterRange(HonParameter):
         if self._min <= value <= self._max and not value % self._step:
             self._value = self._value
         else:
-            raise ValueError(f"min {self._min} max {self._max} step {self._step}")
+            raise ValueError(f"Allowed: min {self._min} max {self._max} step {self._step}")
 
 
 class HonParameterEnum(HonParameter):
@@ -89,11 +89,23 @@ class HonParameterEnum(HonParameter):
         if value in self.values:
             self._value = self._value
         else:
-            raise ValueError(f"values {self._value}")
+            raise ValueError(f"Allowed values {self._value}")
 
 
 class HonParameterProgram(HonParameterEnum):
-    def __init__(self, key, attributes):
-        super().__init__(key, attributes)
-        self._value = attributes["current"]
-        self._values = attributes["values"]
+    def __init__(self, key, command):
+        super().__init__(key, {})
+        self._command = command
+        self._value = command._category
+        self._values = list(command._multi)
+
+    @property
+    def value(self):
+        return self._value
+
+    @value.setter
+    def value(self, value):
+        if value in self.values:
+            self._command.set_program(value)
+        else:
+            raise ValueError(f"Allowed values {self._value}")
